#!/usr/bin/python3
from threading import Lock

class Thread_Set:
    """Thread safe set.

    Only a part of the usual set methods are implemented.
    """

    def __init__(self):
        self.my_set = set()
        self._lock = Lock()

    def add(self, x):
        with self._lock:
            self.my_set.add(x)

    def discard(self, x):
        with self._lock:
            self.my_set.discard(x)

    def clear(self):
        with self._lock:
            self.my_set.clear()

    def copy(self):
        with self._lock:
           r = self.my_set.copy() 
        return r

    def __len__(self):
        with self._lock:
            r = len(self.my_set)
        return r

    def __contains__(self, x):
        with self._lock:
            r = (x in self.my_set)
        return r

    def __repr__(self):
        with self._lock:
            r = self.my_set.__repr__()
        return r

# vim: set et:
